"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require('path');
const fs = require('fs');
const rimraf = require("rimraf");
const alwayscli_1 = require("@alwaysai/alwayscli");
const model_package_cache_1 = require("../../util/model-package-cache");
const winston = require("winston");
function removeCache(modelPath, ignore) {
    let glob = '*';
    if (ignore) {
        const majorVersions = [''];
        const minorVersions = [''];
        ignore.forEach(version => {
            if (version.length === 1) {
                majorVersions.push(version);
            }
            else {
                minorVersions.push(version.split('.')[1]);
            }
        });
        glob = `[!${majorVersions.join('')}].[!${minorVersions.join('')}]*`;
    }
    const removePath = path.join(modelPath, glob);
    winston.debug(removePath);
    rimraf.sync(removePath);
}
exports.modelPrune = alwayscli_1.CliLeaf({
    name: 'prune',
    description: 'Prune models from your model cache',
    positionalInput: alwayscli_1.CliStringInput({
        placeholder: 'Model id ex: alwaysai/human-pose',
        required: true,
    }),
    namedInputs: {
        ignore: alwayscli_1.CliStringArrayInput({
            description: 'Versions to ignore ex: 0.4 0.2',
        }),
    },
    async action(id, opts) {
        const modelPath = path.join(model_package_cache_1.ModelPackageDirectory(), id);
        if (!fs.existsSync(modelPath)) {
            throw new alwayscli_1.CliUsageError(`Model ${id} not found in cache`);
        }
        const ignoreVersions = opts['ignore'];
        if (ignoreVersions) {
            ignoreVersions.forEach(version => {
                if (!fs.existsSync(path.join(modelPath, `${version}.tar.gz`))) {
                    throw new alwayscli_1.CliUsageError(`Ignore version ${version} for model ${id} not found in cache.`);
                }
            });
        }
        removeCache(path.join(model_package_cache_1.ModelPackageDirectory(), id), ignoreVersions);
    },
});
//# sourceMappingURL=prune.js.map