import { undefined } from 'io-ts';
const path = require('path');
const fs = require('fs');

import rimraf = require('rimraf');
import {
  CliUsageError,
  CliLeaf,
  CliStringArrayInput,
  CliStringInput,
} from '@alwaysai/alwayscli';

import { ModelPackageDirectory } from '../../util/model-package-cache';
import * as winston from 'winston';

function removeCache(modelPath: string, ignore: string[] | undefined) {
  let glob = '*';
  if (ignore) {
    const majorVersions = [''];
    const minorVersions = [''];
    ignore.forEach(version => {
      if (version.length === 1) {
        majorVersions.push(version);
      } else {
        minorVersions.push(version.split('.')[1]);
      }
    });
    glob = `[!${majorVersions.join('')}].[!${minorVersions.join('')}]*`;
  }
  const removePath = path.join(modelPath, glob);
  winston.debug(removePath);
  rimraf.sync(removePath);
}

export const modelPrune = CliLeaf({
  name: 'prune',
  description: 'Prune models from your model cache',
  positionalInput: CliStringInput({
    placeholder: 'Model id ex: alwaysai/human-pose',
    required: true,
  }),
  namedInputs: {
    ignore: CliStringArrayInput({
      description: 'Versions to ignore ex: 0.4 0.2',
    }),
  },
  async action(id, opts) {
    const modelPath = path.join(ModelPackageDirectory(), id);
    if (!fs.existsSync(modelPath)) {
      throw new CliUsageError(`Model ${id} not found in cache`);
    }
    const ignoreVersions = opts['ignore'];
    if (ignoreVersions) {
      ignoreVersions.forEach(version => {
        if (!fs.existsSync(path.join(modelPath, `${version}.tar.gz`))) {
          throw new CliUsageError(
            `Ignore version ${version} for model ${id} not found in cache.`,
          );
        }
      });
    }
    removeCache(path.join(ModelPackageDirectory(), id), ignoreVersions);
  },
});
